@@ -3,7 +3,7 @@ mod query;
 mod receiver;
 mod traits;
 
-pub use cw0::Expiration;
+pub use cw_utils::Expiration;
 
 pub use crate::msg::Cw721ExecuteMsg;
 pub use crate::query::{
